@@ -1,4 +1,4 @@
 __version__ = '1.0.0'
 
 from python_bladerf.pylibbladerf import pybladerf  # noqa F401
-from python_bladerf.pybladerf_tools import pybladerf_sweep  # noqa F401
+from python_bladerf.pybladerf_tools import pybladerf_sweep, pybladerf_info  # noqa F401
